summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/parameters/RosegardenParameterBox.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/parameters/RosegardenParameterBox.h')
-rw-r--r--src/gui/editors/parameters/RosegardenParameterBox.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/gui/editors/parameters/RosegardenParameterBox.h b/src/gui/editors/parameters/RosegardenParameterBox.h
index 629245f..c75f875 100644
--- a/src/gui/editors/parameters/RosegardenParameterBox.h
+++ b/src/gui/editors/parameters/RosegardenParameterBox.h
@@ -43,18 +43,19 @@ namespace Rosegarden
/**
* A flat TQFrame, in which a group of parameters can be laid out.
- * Virtual method functions are defined for for requesting a layout
+ * Virtual method functions are defined for for requesting a tqlayout
* style, and returning the single-word to use for labelling the
* box.
*/
-class RosegardenParameterBox : public QFrame
+class RosegardenParameterBox : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
RosegardenParameterBox(const TQString &shortLabel, // e.g. i18n("Track")
const TQString &longLabel, // e.g. i18n("Track Parameters")
- TQWidget *parent = 0,
+ TQWidget *tqparent = 0,
const char *name = 0);
// Ask for a one-word string that can be used to label the widget.
@@ -71,11 +72,11 @@ public:
protected:
void init();
- // List the layout styles that may be requested via a call to setStyle().
+ // List the tqlayout styles that may be requested via a call to setStyle().
enum LayoutMode {
- LANDSCAPE_MODE, // Optimize the layout for a tall and narrow parent.
- PORTRAIT_MODE // Optimize the layout for a short and wide parent.
+ LANDSCAPE_MODE, // Optimize the tqlayout for a tall and narrow tqparent.
+ PORTRAIT_MODE // Optimize the tqlayout for a short and wide tqparent.
};
void setLayoutMode(LayoutMode mode);
@@ -83,7 +84,7 @@ protected:
TQFont m_font;
TQString m_shortLabel; // The string that containers can use for labelling and identification
TQString m_longLabel; // The full title
- LayoutMode m_mode; // The current layout mode.
+ LayoutMode m_mode; // The current tqlayout mode.
};